@@ -1,5 +1,6 @@
 import requests
-import socket
+import json
+import urllib.parse
 from netbox import exceptions
 
 
@@ -29,14 +30,14 @@ class NetboxConnection(object):
             self.session.headers.update({'Content-Type': 'application/json'})
 
         if auth and auth_token:
-            raise ValueError('Only one authentication method is possible. Please use auth or auth_token')
+            raise exceptions.AuthException('Only one authentication method is possible. Please use auth or auth_token')
 
         if extra_headers:
             self.session.headers.update(extra_headers)
 
     def __request(self, method, params=None, key=None, body=None, url=None):
 
-        if method is not 'GET':
+        if method != 'GET':
             if not self.auth_token:
                 raise exceptions.AuthException('Authentication credentials were not provided')
 
@@ -54,25 +55,28 @@ class NetboxConnection(object):
 
         try:
             response = self.session.send(prepared_request)
-        except socket.gaierror:
-            err_msg = 'Unable to find address: {}'.format(self.host)
-            raise socket.gaierror(err_msg)
         except requests.exceptions.ConnectionError:
             err_msg = 'Unable to connect to Netbox host: {}'.format(self.host)
-            raise ConnectionError(err_msg)
+            raise ConnectionError(err_msg) from None
         except requests.exceptions.Timeout:
-            raise TimeoutError('Connection to Netbox host timed out')
+            raise TimeoutError('Connection to Netbox host timed out') from None
         except Exception as e:
             raise Exception(e)
         finally:
             self.close()
 
+        if not 200 <= response.status_code < 300:
+            self.__raise_error(response.status_code, response.content)
+
+        if response.status_code == 204:
+            return response.content
+
         try:
             response_data = response.json()
-        except:
-            response_data = response.content
+        except json.JSONDecodeError:
+            raise exceptions.ServerException(response.content) from None
 
-        return response.ok, response.status_code, response_data
+        return response_data
 
     def get(self, param, key=None, limit=0, **kwargs):
 
@@ -81,21 +85,15 @@ class NetboxConnection(object):
                                             '&'.join('{}={}'.format(key, val) for key, val in kwargs.items()), limit)
         elif key:
             if '_choices' in param:
-                url = '{}{}{}/?limit={}'.format(self.base_url, param, key, limit)
+                url = '{}{}{}/?limit={}'.format(self.base_url, urllib.parse.quote(param), key, limit)
             else:
-                url = '{}{}/?q={}&limit={}'.format(self.base_url, param, key, limit)
+                url = '{}{}/?q={}&limit={}'.format(self.base_url, urllib.parse.quote(param), key, limit)
         else:
-            url = '{}{}?limit={}'.format(self.base_url, param, limit)
+            url = '{}{}?limit={}'.format(self.base_url, urllib.parse.quote(param), limit)
 
-        resp_ok, resp_status, resp_data = self.__request('GET', params=param, key=key, url=url)
+        resp_data = self.__request('GET', params=param, key=key, url=url)
 
-        if resp_ok and resp_status == 200:
-            if 'results' in resp_data:
-                return resp_data['results']
-            else:
-                return resp_data
-        else:
-            return []
+        return resp_data['results']
 
     def put(self, params):
 
@@ -104,15 +102,9 @@ class NetboxConnection(object):
     def patch(self, params, key, **kwargs):
 
         body_data = {key: value for (key, value) in kwargs.items()}
-        resp_ok, resp_status, resp_data = self.__request('PATCH', params=params, key=key, body=body_data)
+        resp_data = self.__request('PATCH', params=params, key=key, body=body_data)
 
-        if resp_ok and resp_status == 200:
-            return resp_data
-
-        if resp_status == 404:
-            raise exceptions.NotFoundException("object not found with id {}".format(key), from_con=True)
-
-        raise exceptions.UpdateException(resp_data)
+        return resp_data
 
     def post(self, params, required_fields, **kwargs):
 
@@ -120,25 +112,33 @@ class NetboxConnection(object):
 
         if kwargs:
             body_data.update({key: value for (key, value) in kwargs.items()})
+        resp_data = self.__request('POST', params=params, body=body_data)
 
-        resp_ok, resp_status, resp_data = self.__request('POST', params=params, body=body_data)
-        if resp_ok and resp_status == 201:
-            return resp_data
-        else:
-            raise exceptions.CreateException(resp_data)
+        return resp_data
 
     def delete(self, params, del_id):
 
         del_str = '{}{}'.format(params, del_id)
-        resp_ok, resp_status, resp_data = self.__request('DELETE', del_str)
-        if resp_ok and resp_status == 204:
-            return True
+        self.__request('DELETE', del_str)
 
-        if resp_status == 404:
-            raise exceptions.NotFoundException("Unable to found object with id {}".format(del_id), from_con=True)
-
-        raise exceptions.DeleteException(resp_data)
+        return True
 
     def close(self):
 
         self.session.close()
+
+    def __raise_error(self, http_status_code, http_response):
+        """Raise error with detailed information from http request."""
+        try:
+            error_msg = json.loads(http_response)
+        except json.JSONDecodeError:
+            error_msg = http_response
+
+        if http_status_code == 404:
+            raise exceptions.NotFoundException(error_msg)
+        elif http_status_code == 403:
+            raise exceptions.AuthorizationException(error_msg)
+        elif http_status_code == 400:
+            raise exceptions.ClientException(error_msg)
+        elif http_status_code == 503:
+            raise exceptions.ServerException(error_msg)
